# Brown Dog Tools Catalog
This application allows users to view available converters and extractors. Authenticated
users can submit new tools and scripted instances. Authenticated administrators can
review submitted tools and then deploy them to the swarm.

## Production Deployment
The production version of this application can be reached at
[https://browndog.ncsa.illinois.edu/toolscatalog/](https://browndog.ncsa.illinois.edu/toolscatalog/)

## Running Locally
The application is developed in Scala with Play version 2.2.

To build and run Tools Catalog you will need the following dependencies installed:

| Tool | Required? | Version | Notes |
| ---- | --------- | ------- | ----- |
| Java JDK | Yes | At least version 1.7 of JAVA. Version 1.8 will work as well. | |
| Scala/SBT| Yes for Development| For windows there are 2 versions, one for 32 bit versions of JAVA and one for 64 bit versions of JAVA. We highly recommend using 64 bit version of JAVA since the 32 bit version can run out of memory.| If you have sbt installed you can use it directly. The other option is to use the sbt executable included in Tools Catalog root folder.|
| Mongo | Yes | Tools Catalog is tested with versions 2.6.8 of MongoDB and up, and will work with versions 3 and higher. | You will need to make sure mongod is running before you start Tools Catalog.
| RabbitMQ | No | We currently are supporting version 3.4.3 of RabbitMQ. | The management plugin will help with debugging. To enable the plugin you will need to execute the following code inside the RabbitMQ folder: `sbin/rabbitmq-plugins enable rabbitmq_management`. To open the management console you can open the following link in your browser: [http://localhost:15672/](http://localhost:15672/). The default username and passwordare _guest/guest_


## Configuration
The application is configured with the standard Play configuration file `conf/application.conf`. The values
in the repo should allow you to run the application in development mode. Any local configuration changes are best
effected with `custom.conf` which is imported at the end of the application conf. You can create your own custom config since this file is referenced
in `.gitignore`

### Local Authentication
Ordinarily the application will authenticate users against the Crowd service running
on `https://opensource.ncsa.illinois.edu`. For testing and development this can be
cumbersome. It is possible override authentication during development by changing
the `auth.debug.mode` property to `true`. The preferred way to do this is to create a file in the `conf` directory
called `custom.conf`. In this file you can override the default setting by adding a single line
```
auth.debug.mode = true
```

The property is only used when the app is running in development or test mode.
It will always authenticate to the email address set in the
`auth.debug.email_address` property.

Set this property to one of the email addresses found in `admin_emails` to
authenticate to a user with admin privileges.

# Running Tools Catalog
To run tools catalog just issue the command
`sbt run`. The application will launch and can be reached at `http://localhost:9000`


## Inserting a test tool
General instructions for working with Tools Catalog can be found in [this
presentation](http://browndog.ncsa.illinois.edu/tutorials/xsede16/09-ToolsCatalog.pptx).

To insert a tool into the repository for testing go through the _Create Tool_ workflow from the _Contribute_ menu.

* On the first page just enter the fields marked as required.
* This will result in a tool validated to **Level 1**. Only **Level 4** tools can be deployed, so continue the workflow
by adding a _Brown Dog Script_.
* The two fields on the _Add Brown Dog Script_ first page are required. Provide
values for them.
* On the second page it is important that you enter values into each of the fields to bring the validation up to **Level
4**. It really doesn't matter what you put in the fields. There is no validation of the values; they just have to be
non-blank.
* Once you have a **Level 4** validated tool, you should click on the _Author Approve_ button to change it from Green to
 white. The white button indicates author approval.
* Now you can go to the _Admin_ page and click on the _Review Brown Dog Scripts_
button. You should see your new tool and script ready for your approval.

## Creating a Brown Dog Instance
The next step is to create a Brown Dog instance where you can deploy your new tool.

* Make sure that RabbitMQ is running.
* Visit your local [RabbitMQ admin page](http://localhost:15672) and click
on the _Admin_ tab. From there click on the _Virtual Hosts_ link and create a new virtual host called `vhost2`.
* Go back to the Brown Dog console and click on the _Configure Brown Dog Instances_ button on the _Admin_ page.
* _Add_ a new deployment and set the _URI String_ to `localhost:5672/vhost2` and the _Login Name_ to `guest`.

## Deploy your Tool to the Brown Dog Instance!
Now you are ready to submit the request to deploy the tool to BD-Swarm.

* Click on the _Deploy Brown Dog Scripts_ button on the _Admin_ tab. You should see your approved script.
* Click on the _Add_ button.
* You should see the _Deploy Script_ page which should have your new Brown Dog Instance listed in the Instance drop down.
* Populate the fields and click `Submit`.
* If the deploy was successful you should see a json message in the RabbitMQ `elasticity_deploy` queue representing your
deployment request.
